@@ -43,34 +43,16 @@ struct RsvgCairoClipRender {
 	cairo_t *cr;
 };
 
-static void
-_set_rsvg_affine (cairo_t *cr, const double affine[6])
-{
-	cairo_matrix_t matrix;
-
-	cairo_matrix_init (&matrix,
-					   affine[0], affine[1],
-					   affine[2], affine[3],
-					   affine[4], affine[5]);
-	cairo_set_matrix (cr, &matrix);
-}
-
 static void
 rsvg_cairo_clip_render_path (RsvgDrawingCtx *ctx, const RsvgBpathDef *bpath_def)
 {
 	RsvgCairoClipRender *render = (RsvgCairoClipRender *)ctx->render;
-	RsvgState *state = rsvg_state_current (ctx);
 	cairo_t *cr;
 	RsvgBpath *bpath;
-	cairo_matrix_t save;
 	int i;
 
 	cr = render->cr;
 
-	cairo_get_matrix (cr, &save);
-
-	_set_rsvg_affine (cr, state->affine);
-
 	if (rsvg_state_current(ctx)->clip_rule == FILL_RULE_EVENODD)
 		cairo_set_fill_rule (((RsvgCairoRender *)ctx->render)->cr, CAIRO_FILL_RULE_EVEN_ODD);
 	else /* state->fill_rule == FILL_RULE_NONZERO */
@@ -99,7 +81,6 @@ rsvg_cairo_clip_render_path (RsvgDrawingCtx *ctx, const RsvgBpathDef *bpath_def)
 			break;
 		}
 	}
-	cairo_set_matrix (cr, &save);
 }
 
 static void rsvg_cairo_clip_render_image (RsvgDrawingCtx *ctx, 
